/* exec4.c - shows how easy it is for a process to run a program

   The exec() family of functions cause a program to be loaded
   into the current process. This means that the code from the
   process that calls exec() gets (completely) overwritten by the
   code of a another program and then the new program is started.

   The execvp() function expects a "command-line" like argument to
   tell it what program to run and what command-line parameters
   to pass to the new program.
*/
#include <unistd.h>
#include <stdio.h>

int main(int argc, char * argv[])
{
   if (1 == argc)
   {
      printf("Usage: %s <command-line>\n", argv[0]);
      return 1;
   }

   /* build a new command-line using this process's command-line */
   char *arglist[argc];
   for (int i = 1; i < argc; ++i)
   {
      arglist[i-1] = argv[i];
   }
   arglist[argc - 1] = 0;

   printf("* * * About to exec %s\n", argv[1]);
   /* execute the command-line (in this process!!) */
   execvp(argv[1], arglist);

   char error[100];
   sprintf(error, "execvp failed on %s", argv[1]);
   perror(error);
   return 1;
}
