/*
   Combine fork() with exec() (and also the wait() function)
   to have a parent process run a program. The parent and
   child processes end up sharing the same console. I do
   not know how to run the child in its own console window
   (as in the Windows operating system).
*/
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/wait.h>

int main()
{
   int my_pid = getpid();                    /* who am i? */
   printf("Parent: my pid is %d\n", my_pid); /* tell the world */

   int fork_rv = fork();

   if ( -1 == fork_rv )  /* check for error */
   {
      perror("fork");
      exit(1);
   }
   else if ( 0 == fork_rv )  /* child */
   {
      execl("/bin/nano", "nano", NULL);
      perror("execl failed");
      exit(1);
   }
   else /* parent */
   {
      printf("I am the parent, my child is %d.\n", fork_rv);
      for (int i = 0; i < 1000; ++i) // what hapens to this output?
         printf("%d\n", i);
      printf("%d is waiting for %d.\n", my_pid, fork_rv);
      int wait_rv = wait(NULL); /* wait for the child to complete */
      printf("%d is done waiting for %d. Wait returned: %d\n", my_pid, fork_rv, wait_rv);
   }

   return 0;
}
