/*
   The fork() system call is the mechanism for creating new
   processes in Linux/Unix/Posix API. It creates an exact
   duplicate of the current process (the duplicate is the
   child process and the original process is the parent).
   If you want a really "different" process, then the child
   process should use a version of the exec function to replace
   this program's code with the code of the new program.
*/
#include <unistd.h>
#include <stdio.h>

int main()
{
   printf("Before fork: parent pid = %d\n", getpid());

   int pid = fork(); /* create a new process */
                     /* child gets pid == 0, parent gets pid == child's pid */

   if ( -1 == pid )  /* check for error */
   {
      perror("fork");
   }
   else if ( 0 == pid ) /* child */
   {
      printf("I am the child, my pid = %d\n", getpid());
   }
   else /* parent */
   {
      printf("I am the parent, my child has pid = %d\n", pid);
   }

   return 0;
}
